==> xdvik-22.77.1.tar.gz: xdvik-22.77.1/texk/xdvik/dvisel.h <==
/*
 * select pages from a DVI file.
 *
 * The original version is:
 * Copyright (c) 1999
 *      WATANABE Takeshi        watanabe@komadori.planet.sci.kobe-u.ac.jp
 *
 * Heavily changed for xdvik:
 * Copyright (c) 2002  the xdvik project team
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT.  IN NO EVENT SHALL ANY AUTHO OF THIS SOFTWARE BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef DVISEL_H
#define DVISEL_H

#include <stdio.h> /* for FILE * */

#include "dvi-init.h"
#include "print-dialog.h" /* for print_or_save_action_t */


/* stacks for communication with selection routines */
struct specials_stack_elem_t {
    char *content;		/* string content */
};

struct specials_stack_t {
    size_t stack_len;
    struct specials_stack_elem_t *items;
};

/* wrapper struct for all kinds of information about selected pages. */
struct select_pages_info_t {
    print_or_save_action_t act;	/* whether we're printing or saving */
    FILE *out_fp;		/* file pointer to write selected pages to */
    FILE *in_fp;		/* file pointer to DVI file */
    char *out_temp;		/* name of temporary file to write selected pages to */
    char *out_final;		/* name of final destination file to write selected pages to */
    int from;			/* lower bound of page range to be selected */
    int to;			/* upper bound of page range to be selected */
    /* callback function that says whether a page should be selected or not;
       will be passed a pointer to the current struct select_pages_info_t,
       and the current page */
    Boolean (*callback)(struct select_pages_info_t *info, int page);
    struct specials_stack_t warn_files;	/* collect warnings about included files */
    dvi_err_flag_t errflag;	/* collect all kinds of errors that can happen while copying */
};

/* functions for selecting/pringing pages */
/*  Boolean select_marked_pages(FILE *fp, struct specials_stack_t *stack); */
/*  Boolean select_pagerange(FILE *fp, int from, int to, struct specials_stack_t *stack); */
/* callbacks */
Boolean check_pagerange(struct select_pages_info_t *info, int pageno);
Boolean check_marked(struct select_pages_info_t *info, int pageno);
void select_pages(struct select_pages_info_t *info);

#endif /* DVISEL_H */

==> xdvik-22.77.2.tar.gz: xdvik-22.77.2/texk/xdvik/dvisel.h <==
/*
 * select pages from a DVI file.
 *
 * The original version is:
 * Copyright (c) 1999
 *      WATANABE Takeshi        watanabe@komadori.planet.sci.kobe-u.ac.jp
 *
 * Heavily changed for xdvik:
 * Copyright (c) 2002  the xdvik project team
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT.  IN NO EVENT SHALL ANY AUTHO OF THIS SOFTWARE BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

#ifndef DVISEL_H
#define DVISEL_H

#include <stdio.h> /* for FILE * */

#include "dvi-init.h"
#include "print-internal.h"

/* callbacks */
Boolean check_pagerange(struct select_pages_info_t *pinfo, int pageno);
Boolean check_marked(struct select_pages_info_t *pinfo, int pageno);
void select_pages(struct select_pages_info_t *pinfo);

#endif /* DVISEL_H */
